@@ -1,7 +1,7 @@
 #ifndef LIBXL_C_H
 #define LIBXL_C_H
 
-#define LIBXL_VERSION 0x03060502
+#define LIBXL_VERSION 0x03080100
 
 #ifdef _UNICODE
 
@@ -9,17 +9,25 @@
     #include "SheetW.h"
     #include "FormatW.h"
     #include "FontW.h"
+    #include "AutoFilterW.h"
+    #include "FilterColumnW.h"
 
     #define xlCreateBook xlCreateBookCW
     #define xlCreateXMLBook xlCreateXMLBookCW
     #define xlBookLoad xlBookLoadW
     #define xlBookSave xlBookSaveW
+    #define xlBookLoadUsingTempFile xlBookLoadUsingTempFileW
+    #define xlBookSaveUsingTempFile xlBookSaveUsingTempFileW
+    #define xlBookLoadPartially xlBookLoadPartiallyW
+    #define xlBookLoadPartiallyUsingTempFile xlBookLoadPartiallyUsingTempFileW
     #define xlBookLoadRaw xlBookLoadRawW
+    #define xlBookLoadRawPartially xlBookLoadRawPartiallyW
     #define xlBookSaveRaw xlBookSaveRawW
     #define xlBookAddSheet xlBookAddSheetW
     #define xlBookInsertSheet xlBookInsertSheetW
     #define xlBookGetSheet xlBookGetSheetW
     #define xlBookSheetType xlBookSheetTypeW
+    #define xlBookMoveSheet xlBookMoveSheetW
     #define xlBookDelSheet xlBookDelSheetW
     #define xlBookSheetCount xlBookSheetCountW
     #define xlBookAddFormat xlBookAddFormatW
@@ -40,6 +48,7 @@
     #define xlBookGetPicture xlBookGetPictureW
     #define xlBookAddPicture xlBookAddPictureW
     #define xlBookAddPicture2 xlBookAddPicture2W
+    #define xlBookAddPictureAsLink xlBookAddPictureAsLinkW
     #define xlBookDefaultFont xlBookDefaultFontW
     #define xlBookSetDefaultFont xlBookSetDefaultFontW
     #define xlBookSetKey xlBookSetKeyW
@@ -71,10 +80,15 @@
     #define xlSheetWriteBlank xlSheetWriteBlankW
     #define xlSheetReadFormula xlSheetReadFormulaW
     #define xlSheetWriteFormula xlSheetWriteFormulaW
+    #define xlSheetWriteFormulaNum xlSheetWriteFormulaNumW
+    #define xlSheetWriteFormulaStr xlSheetWriteFormulaStrW
+    #define xlSheetWriteFormulaBool xlSheetWriteFormulaBoolW
     #define xlSheetReadComment xlSheetReadCommentW
     #define xlSheetWriteComment xlSheetWriteCommentW
+    #define xlSheetRemoveComment xlSheetRemoveCommentW
     #define xlSheetIsDate xlSheetIsDateW
     #define xlSheetReadError xlSheetReadErrorW
+    #define xlSheetWriteError xlSheetWriteErrorW
     #define xlSheetColWidth xlSheetColWidthW
     #define xlSheetRowHeight xlSheetRowHeightW
     #define xlSheetSetCol xlSheetSetColW
@@ -164,14 +178,20 @@
     #define xlSheetDelNamedRange xlSheetDelNamedRangeW
     #define xlSheetNamedRangeSize xlSheetNamedRangeSizeW
     #define xlSheetNamedRange xlSheetNamedRangeW
+    #define xlSheetTableSize xlSheetTableSizeW
+    #define xlSheetTable xlSheetTableW
     #define xlSheetHyperlinkSize xlSheetHyperlinkSizeW
     #define xlSheetHyperlink xlSheetHyperlinkW
     #define xlSheetDelHyperlink xlSheetDelHyperlinkW
     #define xlSheetAddHyperlink xlSheetAddHyperlinkW
+    #define xlSheetAutoFilter xlSheetAutoFilterW
+    #define xlSheetApplyFilter xlSheetApplyFilterW
+    #define xlSheetRemoveFilter xlSheetRemoveFilterW
     #define xlSheetName xlSheetNameW
     #define xlSheetSetName xlSheetSetNameW
     #define xlSheetProtect xlSheetProtectW
     #define xlSheetSetProtect xlSheetSetProtectW
+    #define xlSheetSetProtectEx xlSheetSetProtectExW
     #define xlSheetHidden xlSheetHiddenW
     #define xlSheetSetHidden xlSheetSetHiddenW
     #define xlSheetGetTopLeftView xlSheetGetTopLeftViewW
@@ -181,6 +201,14 @@
     #define xlSheetSetAutoFitArea xlSheetSetAutoFitAreaW
     #define xlSheetAddrToRowCol xlSheetAddrToRowColW
     #define xlSheetRowColToAddr xlSheetRowColToAddrW
+    #define xlSheetSetTabColor xlSheetSetTabColorW
+    #define xlSheetSetTabRgbColor xlSheetSetTabRgbColorW
+    #define xlSheetAddIgnoredError xlSheetAddIgnoredErrorW
+    #define xlSheetAddDataValidation xlSheetAddDataValidationW
+    #define xlSheetAddDataValidationEx xlSheetAddDataValidationExW
+    #define xlSheetAddDataValidationDouble xlSheetAddDataValidationDoubleW
+    #define xlSheetAddDataValidationDoubleEx xlSheetAddDataValidationDoubleExW
+    #define xlSheetRemoveDataValidations xlSheetRemoveDataValidationsW
 
     #define xlFontSize xlFontSizeW
     #define xlFontSetSize xlFontSetSizeW
@@ -250,23 +278,52 @@
     #define xlFormatHidden xlFormatHiddenW
     #define xlFormatSetHidden xlFormatSetHiddenW
 
+    #define xlAutoFilterGetRef xlAutoFilterGetRefW
+    #define xlAutoFilterSetRef xlAutoFilterSetRefW
+    #define xlAutoFilterColumn xlAutoFilterColumnW
+    #define xlAutoFilterColumnSize xlAutoFilterColumnSizeW
+    #define xlAutoFilterColumnByIndex xlAutoFilterColumnByIndexW
+    #define xlAutoFilterGetSortRange xlAutoFilterGetSortRangeW
+    #define xlAutoFilterGetSort xlAutoFilterGetSortW
+    #define xlAutoFilterSetSort xlAutoFilterSetSortW
+
+    #define xlFilterColumnIndex xlFilterColumnIndexW
+    #define xlFilterColumnFilterType xlFilterColumnFilterTypeW
+    #define xlFilterColumnFilterSize xlFilterColumnFilterSizeW
+    #define xlFilterColumnFilter xlFilterColumnFilterW
+    #define xlFilterColumnAddFilter xlFilterColumnAddFilterW
+    #define xlFilterColumnGetTop10 xlFilterColumnGetTop10W
+    #define xlFilterColumnSetTop10 xlFilterColumnSetTop10W
+    #define xlFilterColumnGetCustomFilter xlFilterColumnGetCustomFilterW
+    #define xlFilterColumnSetCustomFilter xlFilterColumnSetCustomFilterW
+    #define xlFilterColumnSetCustomFilterEx xlFilterColumnSetCustomFilterExW
+    #define xlFilterColumnClear xlFilterColumnClearW
+
 #else
 
     #include "BookA.h"
     #include "SheetA.h"
     #include "FormatA.h"
     #include "FontA.h"
+    #include "AutoFilterA.h"
+    #include "FilterColumnA.h"
 
     #define xlCreateBook xlCreateBookCA
     #define xlCreateXMLBook xlCreateXMLBookCA
     #define xlBookLoad xlBookLoadA
     #define xlBookSave xlBookSaveA
+    #define xlBookLoadUsingTempFile xlBookLoadUsingTempFileA
+    #define xlBookSaveUsingTempFile xlBookSaveUsingTempFileA
+    #define xlBookLoadPartially xlBookLoadPartiallyA
+    #define xlBookLoadPartiallyUsingTempFile xlBookLoadPartiallyUsingTempFileA
     #define xlBookLoadRaw xlBookLoadRawA
+    #define xlBookLoadRawPartially xlBookLoadRawPartiallyA
     #define xlBookSaveRaw xlBookSaveRawA
     #define xlBookAddSheet xlBookAddSheetA
     #define xlBookInsertSheet xlBookInsertSheetA
     #define xlBookGetSheet xlBookGetSheetA
     #define xlBookSheetType xlBookSheetTypeA
+    #define xlBookMoveSheet xlBookMoveSheetA
     #define xlBookDelSheet xlBookDelSheetA
     #define xlBookSheetCount xlBookSheetCountA
     #define xlBookAddFormat xlBookAddFormatA
@@ -287,6 +344,7 @@
     #define xlBookGetPicture xlBookGetPictureA
     #define xlBookAddPicture xlBookAddPictureA
     #define xlBookAddPicture2 xlBookAddPicture2A
+    #define xlBookAddPictureAsLink xlBookAddPictureAsLinkA
     #define xlBookDefaultFont xlBookDefaultFontA
     #define xlBookSetDefaultFont xlBookSetDefaultFontA
     #define xlBookSetKey xlBookSetKeyA
@@ -318,10 +376,15 @@
     #define xlSheetWriteBlank xlSheetWriteBlankA
     #define xlSheetReadFormula xlSheetReadFormulaA
     #define xlSheetWriteFormula xlSheetWriteFormulaA
+    #define xlSheetWriteFormulaNum xlSheetWriteFormulaNumA
+    #define xlSheetWriteFormulaStr xlSheetWriteFormulaStrA
+    #define xlSheetWriteFormulaBool xlSheetWriteFormulaBoolA
     #define xlSheetReadComment xlSheetReadCommentA
     #define xlSheetWriteComment xlSheetWriteCommentA
+    #define xlSheetRemoveComment xlSheetRemoveCommentA
     #define xlSheetIsDate xlSheetIsDateA
     #define xlSheetReadError xlSheetReadErrorA
+    #define xlSheetWriteError xlSheetWriteErrorA
     #define xlSheetColWidth xlSheetColWidthA
     #define xlSheetRowHeight xlSheetRowHeightA
     #define xlSheetSetCol xlSheetSetColA
@@ -411,14 +474,20 @@
     #define xlSheetDelNamedRange xlSheetDelNamedRangeA
     #define xlSheetNamedRangeSize xlSheetNamedRangeSizeA
     #define xlSheetNamedRange xlSheetNamedRangeA
+    #define xlSheetTableSize xlSheetTableSizeA
+    #define xlSheetTable xlSheetTableA
     #define xlSheetHyperlinkSize xlSheetHyperlinkSizeA
     #define xlSheetHyperlink xlSheetHyperlinkA
     #define xlSheetDelHyperlink xlSheetDelHyperlinkA
     #define xlSheetAddHyperlink xlSheetAddHyperlinkA
+    #define xlSheetAutoFilter xlSheetAutoFilterA
+    #define xlSheetApplyFilter xlSheetApplyFilterA
+    #define xlSheetRemoveFilter xlSheetRemoveFilterA
     #define xlSheetName xlSheetNameA
     #define xlSheetSetName xlSheetSetNameA
     #define xlSheetProtect xlSheetProtectA
     #define xlSheetSetProtect xlSheetSetProtectA
+    #define xlSheetSetProtectEx xlSheetSetProtectExA
     #define xlSheetHidden xlSheetHiddenA
     #define xlSheetSetHidden xlSheetSetHiddenA
     #define xlSheetGetTopLeftView xlSheetGetTopLeftViewA
@@ -428,6 +497,14 @@
     #define xlSheetSetAutoFitArea xlSheetSetAutoFitAreaA
     #define xlSheetAddrToRowCol xlSheetAddrToRowColA
     #define xlSheetRowColToAddr xlSheetRowColToAddrA
+    #define xlSheetSetTabColor xlSheetSetTabColorA
+    #define xlSheetSetTabRgbColor xlSheetSetTabRgbColorA
+    #define xlSheetAddIgnoredError xlSheetAddIgnoredErrorA
+    #define xlSheetAddDataValidation xlSheetAddDataValidationA
+    #define xlSheetAddDataValidationEx xlSheetAddDataValidationExA
+    #define xlSheetAddDataValidationDouble xlSheetAddDataValidationDoubleA
+    #define xlSheetAddDataValidationDoubleEx xlSheetAddDataValidationDoubleExA
+    #define xlSheetRemoveDataValidations xlSheetRemoveDataValidationsA
 
     #define xlFontSize xlFontSizeA
     #define xlFontSetSize xlFontSetSizeA
@@ -497,6 +574,27 @@
     #define xlFormatHidden xlFormatHiddenA
     #define xlFormatSetHidden xlFormatSetHiddenA
 
+    #define xlAutoFilterGetRef xlAutoFilterGetRefA
+    #define xlAutoFilterSetRef xlAutoFilterSetRefA
+    #define xlAutoFilterColumn xlAutoFilterColumnA
+    #define xlAutoFilterColumnSize xlAutoFilterColumnSizeA
+    #define xlAutoFilterColumnByIndex xlAutoFilterColumnByIndexA
+    #define xlAutoFilterGetSortRange xlAutoFilterGetSortRangeA
+    #define xlAutoFilterGetSort xlAutoFilterGetSortA
+    #define xlAutoFilterSetSort xlAutoFilterSetSortA
+
+    #define xlFilterColumnIndex xlFilterColumnIndexA
+    #define xlFilterColumnFilterType xlFilterColumnFilterTypeA
+    #define xlFilterColumnFilterSize xlFilterColumnFilterSizeA
+    #define xlFilterColumnFilter xlFilterColumnFilterA
+    #define xlFilterColumnAddFilter xlFilterColumnAddFilterA
+    #define xlFilterColumnGetTop10 xlFilterColumnGetTop10A
+    #define xlFilterColumnSetTop10 xlFilterColumnSetTop10A
+    #define xlFilterColumnGetCustomFilter xlFilterColumnGetCustomFilterA
+    #define xlFilterColumnSetCustomFilter xlFilterColumnSetCustomFilterA
+    #define xlFilterColumnSetCustomFilterEx xlFilterColumnSetCustomFilterExA
+    #define xlFilterColumnClear xlFilterColumnClearA
+
 #endif
 
 #endif
